@@ -3,6 +3,9 @@
 # Monitor System 
 # Copyright Daniel Mehrmann (Akusari) 2020-2023
 #
+# LOG:
+# - 16.01.25: Add "mce: [Hardware Error]" syntax
+# - 10.02.25: Add "psi: inconsistent task state" syntax
 
 #
 # configuration
@@ -86,17 +89,17 @@ done
 #fi
 
 #
-# disk errors
+# disk/hardware errors
 #
 
 if [ "$use_dmesg" == "yes" ]; then
-   /usr/bin/dmesg |grep -E 'ata[0-1].00: failed|ata[0-3].00: error|FAILED|Sense Key|Unrecovered|read error|sector' |grep -v multi |while read -r output; do
+   /usr/bin/dmesg |grep -E 'ata[0-1].00: failed|ata[0-3].00: error|FAILED|Sense Key|Unrecovered|read error|sector|\[Hardware Error\]|Register Dump|inconsistent task state' |grep -v multi |while read -r output; do
       echo "$output" >> $report
       echo "Found error" > $disk_error
    done
 else
    echo "Running user friendly dmesg..."
-   /usr/bin/journalctl --since=-12min --dmesg -o short-monotonic --no-hostname --no-pager |grep -E 'ata[0-1].00: failed|ata[0-3].00: error|FAILED|Sense Key|Unrecovered|read error|sector' |grep -v multi |while read -r output; do
+   /usr/bin/journalctl --since=-12min --dmesg -o short-monotonic --no-hostname --no-pager |grep -E 'ata[0-1].00: failed|ata[0-3].00: error|FAILED|Sense Key|Unrecovered|read error|sector|\[Hardware Error\]|Register Dump' |grep -v multi |while read -r output; do
       echo "$output" >> $report
       echo "Found error" > $disk_error
    done
